@@ -36,11 +36,10 @@
 #endif
 
 #ifdef __linux__
-
 #define OSS_MIXER
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__bsdi__) || defined(_UNIXWARE)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__bsdi__) || defined(_UNIXWARE)
 #define OSS_MIXER
 #endif
 
@@ -50,9 +49,6 @@
 
 // PORTING: add #ifdef PLATFORM , commands , #endif, add your new mixer below
 
-// Compiled by its own!
-//#include "backends/mixer_mpris2.cpp"
-
 #if defined(SUN_MIXER)
 #include "backends/mixer_sun.cpp"
 #endif
@@ -76,7 +72,7 @@
 #endif
 
 
-// Possibly encapsualte by #ifdef HAVE_DBUS
+// Possibly encapsulated by #ifdef HAVE_DBUS
 Mixer_Backend* MPRIS2_getMixer(Mixer *mixer, int device );
 QString MPRIS2_getDriverName();
 
