@@ -28,57 +28,49 @@
 
 #include <klocalizedstring.h>
 
-#include "core/ControlManager.h"
-#include "core/GlobalConfig.h"
-#include "core/mixdevice.h"
 #include "core/mixer.h"
+#include "gui/kmixtoolbox.h"
 
 /**
  * Creates a dialog to choose mixers from. All currently known mixers will be shown, and the given mixerID's
  * will be preselected.
  *
  * @param mixerIds A set of preselected mixer ID's
- * @param noButtons is a migration option. When DialogChooseBackends has been integrated as a Tab, it will be removed.
  */
-DialogChooseBackends::DialogChooseBackends(QWidget* parent, const QSet<QString>& mixerIds)
+DialogChooseBackends::DialogChooseBackends(QWidget *parent, const QSet<QString> &mixerIds)
   :  QWidget(parent), modified(false)
 {
-//    setCaption( i18n( "Select Mixers" ) );
-//   	setButtons( None );
-
-   _layout = 0;
    createWidgets(mixerIds);
-
 }
 
 /**
- * Create basic widgets of the Dialog.
+ * Create basic widgets of the dialogue.
  */
-void DialogChooseBackends::createWidgets(const QSet<QString>& mixerIds)
+void DialogChooseBackends::createWidgets(const QSet<QString> &mixerIds)
 {
-    _layout = new QVBoxLayout(this);
-    _layout->setContentsMargins(0, 0, 0, 0);
+    QVBoxLayout *vLayout = new QVBoxLayout(this);
+    vLayout->setContentsMargins(0, 0, 0, 0);
 
-    if ( !Mixer::mixers().isEmpty() )
+    QLabel *topLabel = new QLabel(i18n("Mixers to show in the popup volume control:"), this);
+    vLayout->addWidget(topLabel);
+
+    createPage(mixerIds);
+    vLayout->addWidget(m_mixerList, 1);
+    topLabel->setBuddy(m_mixerList);
+
+    if (Mixer::mixers().isEmpty())
     {
-        m_listLabel = new QLabel( i18n("Mixers to show in the popup volume control:"), this);
-        _layout->addWidget(m_listLabel);
-        createPage(mixerIds);
-    }
-    else
-    {
-        // TODO: use KMessageWidget
-        m_listLabel = new QLabel( i18n("No sound card is installed or currently plugged in."), this);
-        _layout->addWidget(m_listLabel);
+	QWidget *noMixersWarning = KMixToolBox::noDevicesWarningWidget(this);
+        vLayout->addWidget(noMixersWarning);
+	m_mixerList->setEnabled(false);
     }
 }
 
 
 /**
- * Create RadioButton's for the Mixer with number 'mixerId'.
- * @par mixerId The Mixer, for which the RadioButton's should be created.
+ * Create selection list for the specified mixers.
  */
-void DialogChooseBackends::createPage(const QSet<QString>& mixerIds)
+void DialogChooseBackends::createPage(const QSet<QString> &mixerIds)
 {
 	m_mixerList = new QListWidget(this);
 	m_mixerList->setUniformItemSizes(true);
@@ -88,25 +80,23 @@ void DialogChooseBackends::createPage(const QSet<QString>& mixerIds)
 #ifndef QT_NO_ACCESSIBILITY
 	m_mixerList->setAccessibleName(i18n("Select Mixers"));
 #endif
-	m_listLabel->setBuddy(m_mixerList);
-
-	_layout->addWidget(m_mixerList);
-
 	bool hasMixerFilter = !mixerIds.isEmpty();
 	qCDebug(KMIX_LOG) << "MixerIds=" << mixerIds;
-	foreach ( Mixer* mixer, Mixer::mixers())
+	for (const Mixer *mixer : Mixer::mixers())
 	{
             QListWidgetItem *item = new QListWidgetItem(m_mixerList);
             item->setText(mixer->readableName(true));
             item->setSizeHint(QSize(1, 16));
+            item->setIcon(QIcon::fromTheme(mixer->iconName()));
             item->setFlags(Qt::ItemIsEnabled|Qt::ItemIsUserCheckable|Qt::ItemNeverHasChildren);
+            item->setData(Qt::UserRole, mixer->id());
+
             const bool mixerShouldBeShown = !hasMixerFilter || mixerIds.contains(mixer->id());
             item->setCheckState(mixerShouldBeShown ? Qt::Checked : Qt::Unchecked);
-            item->setData(Qt::UserRole, mixer->id());
 	}
 
-        connect(m_mixerList, SIGNAL(itemChanged(QListWidgetItem*)), SLOT(backendsModifiedSlot()));
-        connect(m_mixerList, SIGNAL(itemActivated(QListWidgetItem*)), SLOT(itemActivatedSlot(QListWidgetItem*)));
+        connect(m_mixerList, &QListWidget::itemChanged, this, &DialogChooseBackends::backendsModifiedSlot);
+        connect(m_mixerList, &QListWidget::itemActivated, this, &DialogChooseBackends::itemActivatedSlot);
 }
 
 QSet<QString> DialogChooseBackends::getChosenBackends()
