@@ -39,14 +39,10 @@
 #include "gui/guiprofile.h"
 #include "gui/volumeslider.h"
 #include "gui/viewbase.h"
-#include "gui/ksmallslider.h"
 #include "gui/verticaltext.h"
 #include "gui/toggletoolbutton.h"
 
 
-bool MDWSlider::debugMe = false;
-
-
  /**
  * MixDeviceWidget that represents a single mix device, including PopUp, muteLED, ...
  *
@@ -75,7 +71,7 @@ MDWSlider::MDWSlider(shared_ptr<MixDevice> md, MixDeviceWidget::MDWFlags flags,
 
     createActions();
     createWidgets();
-    createShortcutActions();
+    createGlobalActions();
 
     // Yes, this looks odd - monitor all events sent to myself by myself?
     // But it's so that wheel events over the MDWSlider background can be
@@ -96,27 +92,20 @@ MDWSlider::~MDWSlider()
 
 void MDWSlider::createActions()
 {
-    // create actions (on _mdwActions, see MixDeviceWidget)
-    KToggleAction *taction = _mdwActions->add<KToggleAction>( "stereo" );
+    // create actions (in channelActions(), see MixDeviceWidget)
+	KToggleAction *taction = channelActions()->add<KToggleAction>( "stereo" );
     taction->setText( i18n("Split Channels") );
     connect( taction, SIGNAL(triggered(bool)), SLOT(toggleStereoLinked()) );
 
-//    QAction *action;
-//    if ( ! mixDevice()->mixer()->isDynamic() ) {
-//        action = _mdwActions->add<KToggleAction>( "hide" );
-//        action->setText( i18n("&Hide") );
-//        connect( action, SIGNAL(triggered(bool)), SLOT(setDisabled(bool)) );
-//    }
-
     if( mixDevice()->hasMuteSwitch() )
     {
-        taction = _mdwActions->add<KToggleAction>( "mute" );
+        taction = channelActions()->add<KToggleAction>( "mute" );
         taction->setText( i18n("Mute") );
         connect( taction, SIGNAL(toggled(bool)), SLOT(toggleMuted()) );
     }
 
     if( mixDevice()->captureVolume().hasSwitch() ) {
-        taction = _mdwActions->add<KToggleAction>( "recsrc" );
+        taction = channelActions()->add<KToggleAction>( "recsrc" );
         taction->setText( i18n("Capture") );
         connect( taction, SIGNAL(toggled(bool)), SLOT(toggleRecsrc()) );
     }
@@ -125,64 +114,76 @@ void MDWSlider::createActions()
         m_moveMenu = new QMenu( i18n("Use Device"), this);
         connect( m_moveMenu, SIGNAL(aboutToShow()), SLOT(showMoveMenu()) );
     }
-
-    QAction* qaction = _mdwActions->addAction( "keys" );
-    qaction->setText( i18n("Channel Shortcuts...") );
-    connect( qaction, SIGNAL(triggered(bool)), SLOT(defineKeys()) );
 }
 
-void MDWSlider::addGlobalShortcut(QAction* qaction, const QString& label, bool dynamicControl)
-{
-	QString finalLabel(label);
-	finalLabel += " - " + mixDevice()->readableName() + ", " + mixDevice()->mixer()->readableName();
 
-	qaction->setText(label);
-	if (!dynamicControl)
+void MDWSlider::createGlobalActions()
+{
+	const shared_ptr<MixDevice> md = mixDevice();
+	const Mixer *mixer = md->mixer();
+
+	// I don't understand the former logic here.  This variable and the comment
+	// in MDWSlider::addGlobalShortcut() say that there are no shortcuts
+	// assigned for a virtual or dynamic control - which makes sense.  However,
+	// for such a control an action was created but its triggered() signal was
+	// never connected to anything - so even if the action was accessible from
+	// the GUI it would have done nothing.
+	//
+	// Possibly what was intended was that the shortcut should be local to KMix.
+	// However, that doesn't make sense either - in MixDeviceWidget::defineKeys()
+	// (which is now MixDeviceWidget::configureShortcuts()), only the global
+	// shortcuts are allowed to be edited.
+	//
+	// In order to keep things simple, do not assign any shortcuts for a
+	// virtual/dynamic control.
+	if (mixer->isDynamic()) return;
+
+	// The following actions are created for the desktop "Global Shortcuts" settings.
+	// It would appear that the discussion and caution below was only required
+	// for KDE4 and has been fixed in KF5.
+	//
+	// Note that global shortcuts are saved with the name as set with QAction::setText(),
+	// instead of their internal action name which is the QObject::objectName().
+        // This is a bug according to the kde-core-devel thread "Global shortcuts are saved with
+	// their text-name and not..." at https://marc.info/?t=119901891400001&r=1&w=2
+	//
+	// Work around this by setting a text that is unique, but still readable for the user.
+
+	// A suffix string to identify the control in the global shortcut configuration.
+	// This should not be I18N'ed so that the assignment is independent of the
+	// display language.
+	const QString actionSuffix  = QString("%1@%2").arg(md->readableName(), mixer->readableName());
+
+	// -3- MUTE VOLUME SHORTCUT -----------------------------------------
+	QAction *act = new QAction(i18nc("1=device name, 2=control name",
+					 "Mute %2 on %1",
+					 mixer->readableName(), md->readableName()), this);
+	globalActions()->addAction(QString("toggle-mute-")+actionSuffix, act);
+	KGlobalAccel::setGlobalShortcut(act, QKeySequence());
+	connect(act, &QAction::triggered, this, &MDWSlider::toggleMuted);
+
+	// Only create volume actions if there are either any playback or capture
+	// sliders present.  It is assumed that there cannot be both.
+	if (m_slidersPlayback.count()!=0 || m_slidersCapture.count()!=0)
 	{
-		// virtual / dynamic controls won't get shortcuts
-		//     #ifdef __GNUC__
-		//     #warning GLOBAL SHORTCUTS ARE NOW ASSIGNED TO ALL CONTROLS, as enableGlobalShortcut(), has not been committed
-		//     #endif
-		//   b->enableGlobalShortcut();
-		// enableGlobalShortcut() is not there => use workaround
-		KGlobalAccel::setGlobalShortcut(qaction, QKeySequence());
+		// -1- INCREASE VOLUME SHORTCUT -----------------------------------------
+		act = new QAction(i18nc("1=device name, 2=control name",
+					"Increase volume of %2 on %1",
+					mixer->readableName(), md->readableName()), this);
+		globalActions()->addAction(QString("increase-volume-")+actionSuffix, act);
+		KGlobalAccel::setGlobalShortcut(act, QKeySequence());
+		connect(act, &QAction::triggered, this, &MDWSlider::increaseVolume);
+
+		// -2- DECREASE VOLUME SHORTCUT -----------------------------------------
+		act = new QAction(i18nc("1=device name, 2=control name",
+					"Decrease volume of %2 on %1",
+					mixer->readableName(), md->readableName()), this);
+		globalActions()->addAction(QString("decrease-volume-")+actionSuffix, act);
+		KGlobalAccel::setGlobalShortcut(act, QKeySequence());
+		connect(act, &QAction::triggered, this, &MDWSlider::decreaseVolume);
 	}
 }
 
-void MDWSlider::createShortcutActions()
-{
-	bool dynamicControl = mixDevice()->mixer()->isDynamic();
-    // The following actions are for the "Configure Shortcuts" dialog
-    /* PLEASE NOTE THAT global shortcuts are saved with the name as set with setName(), instead of their action name.
-        This is a bug according to the thread "Global shortcuts are saved with their text-name and not their action-name - Bug?" on kcd.
-        I work around this by using a text with setText() that is unique, but still readable to the user.
-    */
-    QString actionSuffix  = QString(" - %1, %2").arg( mixDevice()->readableName(), mixDevice()->mixer()->readableName() );
-    QAction *bi, *bd, *bm;
-
-    // -1- INCREASE VOLUME SHORTCUT -----------------------------------------
-    bi = _mdwPopupActions->addAction( QString("Increase volume %1").arg( actionSuffix ) );
-    QString increaseVolumeName = i18n( "Increase Volume" );
-	addGlobalShortcut(bi, increaseVolumeName, dynamicControl);
-   	if ( ! dynamicControl )
-        connect( bi, SIGNAL(triggered(bool)), SLOT(increaseVolume()) );
-
-    // -2- DECREASE VOLUME SHORTCUT -----------------------------------------
-    bd = _mdwPopupActions->addAction( QString("Decrease volume %1").arg( actionSuffix ) );
-    QString decreaseVolumeName = i18n( "Decrease Volume" );
-	addGlobalShortcut(bd, decreaseVolumeName, dynamicControl);
-	if ( ! dynamicControl )
-		connect(bd, SIGNAL(triggered(bool)), SLOT(decreaseVolume()));
-
-    // -3- MUTE VOLUME SHORTCUT -----------------------------------------
-    bm = _mdwPopupActions->addAction( QString("Toggle mute %1").arg( actionSuffix ) );
-    QString muteVolumeName = i18n( "Toggle Mute" );
-	addGlobalShortcut(bm, muteVolumeName, dynamicControl);
-   	if ( ! dynamicControl )
-        connect( bm, SIGNAL(triggered(bool)), SLOT(toggleMuted()) );
-
-}
-
 
 QSizePolicy MDWSlider::sizePolicy() const
 {
@@ -229,27 +230,9 @@ void MDWSlider::setLabelExtent(int extent)
 }
 
 
-/**
- * Alignment helper
- */
-bool MDWSlider::hasMuteButton() const
-{
-	return (m_muteButton!=nullptr);
-}
-
-
-/**
- * See "hasMuteButton"
- */
-bool MDWSlider::hasCaptureLED() const
-{
-	return (m_captureButton!=nullptr);
-}
-
 void MDWSlider::guiAddCaptureButton(const QString &captureTooltipText)
 {
 	m_captureButton = new ToggleToolButton("media-record", this);
-	m_captureButton->setSmallSize(flags() & MixDeviceWidget::SmallSize);
 	m_captureButton->installEventFilter(this);
 	connect(m_captureButton, SIGNAL(clicked(bool)), this, SLOT(toggleRecsrc()));
 	m_captureButton->setToolTip(captureTooltipText);
@@ -259,7 +242,6 @@ void MDWSlider::guiAddMuteButton(const QString &muteTooltipText)
 {
 	m_muteButton = new ToggleToolButton("audio-volume-high", this);
 	m_muteButton->setInactiveIcon("audio-volume-muted");
-	m_muteButton->setSmallSize(flags() & MixDeviceWidget::SmallSize);
 	m_muteButton->installEventFilter(this);
 	connect(m_muteButton, SIGNAL(clicked(bool)), this, SLOT(toggleMuted()));
 	m_muteButton->setToolTip(muteTooltipText);
@@ -276,10 +258,20 @@ void MDWSlider::guiAddControlLabel(Qt::Alignment alignment, const QString &chann
 void MDWSlider::guiAddControlIcon(const QString &tooltipText)
 {
 	m_controlIcon = new QLabel(this);
-	ToggleToolButton::setIndicatorIcon(mixDevice()->iconName(), m_controlIcon,
-					   (flags() & MixDeviceWidget::SmallSize));
+	ToggleToolButton::setIndicatorIcon(mixDevice()->iconName(), m_controlIcon);
 	m_controlIcon->setToolTip(tooltipText);
 	m_controlIcon->installEventFilter(this);
+
+	// A MPRIS2 application's icon name is obtained from its desktop file.
+	// Finding the desktop file is an asynchronous DBus operation which
+	// could in theory happen after the MDWSlider has been created (which
+	// would have used the fallback icon name).  So update the indicator
+	// icon on a signal.
+	connect(mixDevice().get(), &MixDevice::iconNameChanged,
+		this, [this](const QString &newName) {
+			      qDebug() << "for" << mixDevice()->readableName() << "new icon" << newName;
+			      ToggleToolButton::setIndicatorIcon(newName, m_controlIcon);
+		      });
 }
 
 QWidget *MDWSlider::guiAddButtonSpacer()
@@ -307,8 +299,7 @@ QSize MDWSlider::controlButtonSize()
 	if (!m_controlButtonSize.isValid())		// not calculated yet
 	{
 		auto *buttonSpacer = new QToolButton();
-		ToggleToolButton::setIndicatorIcon("unknown", buttonSpacer,
-						   (flags() & MixDeviceWidget::SmallSize));
+		ToggleToolButton::setIndicatorIcon("unknown", buttonSpacer);
 		m_controlButtonSize = buttonSpacer->sizeHint();
 		qCDebug(KMIX_LOG) << m_controlButtonSize;
 		delete buttonSpacer;
@@ -625,13 +616,12 @@ void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
                             QList<QAbstractSlider *>& ref_sliders, const QString &tooltipText)
 {
 	const int minSliderSize = fontMetrics().height() * 10;
-	long minvol = vol.minVolume();
-	long maxvol = vol.maxVolume();
+	const long minvol = vol.minVolume();
+	const long maxvol = vol.maxVolume();
 
-	QMap<Volume::ChannelID, VolumeChannel> vols = vol.getVolumes();
-
-	foreach (VolumeChannel vc, vols )
-	{
+	const QMap<Volume::ChannelID, VolumeChannel> vols = vol.getVolumes();
+	for (const VolumeChannel &vc : vols)
+	{						// for all channels of this device
 		//qCDebug(KMIX_LOG) << "Add label to " << vc.chid << ": " <<  Volume::channelNameReadable(vc.chid);
 		QWidget *subcontrolLabel;
 
@@ -641,31 +631,31 @@ void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
 		subcontrolLabel = createLabel(this, subcontrolTranslation, orientation(), true);
 		volLayout->addWidget(subcontrolLabel);
 
-		QAbstractSlider* slider;
-		if (flags() & MixDeviceWidget::SmallSize)
-		{
-			slider = new KSmallSlider( minvol, maxvol, (maxvol-minvol+1) / Volume::VOLUME_PAGESTEP_DIVISOR,
-						   vol.getVolume( vc.chid ), orientation(), this );
-		} // small
-		else  {
-			slider = new VolumeSlider(orientation(), this);
-			slider->setMinimum(minvol);
-			slider->setMaximum(maxvol);
-			slider->setPageStep(maxvol / Volume::VOLUME_PAGESTEP_DIVISOR);
-			slider->setValue(  vol.getVolume( vc.chid ) );
-			volumeValues.push_back( vol.getVolume( vc.chid ) );
-			
-			extraData(slider).setSubcontrolLabel(subcontrolLabel);
+		VolumeSlider *slider = new VolumeSlider(orientation(), this);
+		slider->setMinimum(minvol);
+		slider->setMaximum(maxvol);
 
-			if (orientation()==Qt::Vertical) slider->setMinimumHeight(minSliderSize);
-			else slider->setMinimumWidth(minSliderSize);
-			if ( !profileControl()->getBackgroundColor().isEmpty() ) {
-				slider->setStyleSheet("QSlider { background-color: " + profileControl()->getBackgroundColor() + " }");
-			}
-		} // not small
+		// Set the slider page step to be the same as the configured volume step.
+		// If that volume step is the minimum possible value (1), then set it
+		// to 2 so that it is bigger than the single step.
+		int pageStep = vol.volumeStep(false);
+		if (pageStep==1) pageStep = 2;
+		slider->setPageStep(pageStep);
+		// Don't show too many tick marks if the page step is small.
+		if (pageStep<10) slider->setTickInterval(qRound((maxvol-minvol)/10.0));
+
+		slider->setValue(vol.getVolume(vc.chid));
+		volumeValues.push_back(vol.getVolume(vc.chid));
+
+		if (orientation()==Qt::Vertical) slider->setMinimumHeight(minSliderSize);
+		else slider->setMinimumWidth(minSliderSize);
+		if ( !profileControl()->getBackgroundColor().isEmpty() ) {
+			slider->setStyleSheet("QSlider { background-color: " + profileControl()->getBackgroundColor() + " }");
+		}
+
+		slider->setSubControlLabel(subcontrolLabel);
+		slider->setChannelId(vc.chid);
 
-		extraData(slider).setChid(vc.chid);
-//		slider->installEventFilter( this );
 		if ( type == 'p' ) {
 			slider->setToolTip( tooltipText );
 		}
@@ -676,29 +666,12 @@ void MDWSlider::addSliders( QBoxLayout *volLayout, char type, Volume& vol,
 
 		volLayout->addWidget( slider ); // add to layout
 		ref_sliders.append ( slider ); // add to list
-		//ref_slidersChids.append(vc.chid);
+
 		connect( slider, SIGNAL(valueChanged(int)), SLOT(volumeChange(int)) );
 		connect( slider, SIGNAL(sliderPressed()), SLOT(sliderPressed()) );
 		connect( slider, SIGNAL(sliderReleased()), SLOT(sliderReleased()) );
 		
-	} // for all channels of this device
-}
-
-/**
- * Return the VolumeSliderExtraData from either VolumeSlider or KSmallSlider.
- * You MUST extend this method, should you decide to add more Slider Widget classes.
- *
- * @param slider
- * @return
- */
-VolumeSliderExtraData& MDWSlider::extraData(QAbstractSlider *slider)
-{
-  VolumeSlider* sl = qobject_cast<VolumeSlider*>(slider);
-  if ( sl )
-	  return sl->extraData;
-  
-  KSmallSlider* sl2 = qobject_cast<KSmallSlider*>(slider);
-  return sl2->extraData;
+	}
 }
 
 
@@ -747,32 +720,36 @@ MDWSlider::setStereoLinkedInternal(QList<QAbstractSlider *>& ref_sliders, bool s
 	  return;
 
 	bool first = true;
-	foreach ( QAbstractSlider* slider1, ref_sliders )
+	for (QAbstractSlider *slider : ref_sliders)
 	{
-		slider1->setVisible(!m_linked || first); // One slider (the 1st) is always shown
-		extraData(slider1).getSubcontrolLabel()->setVisible(!m_linked && showSubcontrolLabels); // (*)
+		slider->setVisible(!m_linked || first); // One slider (the 1st) is always shown
+
+		const VolumeSlider *vs = qobject_cast<VolumeSlider *>(slider);
+		// cesken: Not including "|| first" in the check below because the text would
+		// not look nice:  it would show "Left" or "Capture Left", while it should
+		// be "Playback" and "Capture" in the "linked" case.
+		//
+		// But the only affected situation is when we have playback AND capture on
+		// the same control, where we show no label.  It would be nice to at least
+		// put a "Capture" label on the capture subcontrol instead.  To achieve this
+		// we would need to change the text on the first capture subcontrol dynamically.
+		// This can be done, but I'll leave this open for now.
+		if (vs!=nullptr) vs->subControlLabel()->setVisible(!m_linked && showSubcontrolLabels);
+
 		first = false;
-		/* (*) cesken: I have excluded the "|| first" check because the text would not be nice:
-		 *     It would be "Left" or "Capture Left", while it should be "Playback" and "Capture" in the "linked" case.
-		 *
-		 *     But the only affected situation is when we have playback AND capture on the same control, where we show no label.
-		 *     It would be nice to put at least a "Capture" label on the capture subcontrol instead.
-		 *     To achieve this we would need to exchange the Text on the first capture subcontrol dynamically. This can
-		 *     be done, but I'll leave this open for now.
-		 */
 	}
 
-
-
-	// Redo the tickmarks to last slider in the slider list.
-	// The implementation is not obvious, so lets explain:
-	// We ALWAYS have tickmarks on the LAST slider. Sometimes the slider is not shown, and then we just don't bother.
-	// a) So, if the last slider has tickmarks, we can always call setTicks( true ).
-	// b) if the last slider has NO tickmarks, there ae no tickmarks at all, and we don't need to redo the tickmarks.
-	QSlider* slider = qobject_cast<QSlider*>( ref_sliders.last() );
-	if( slider && slider->tickPosition() != QSlider::NoTicks) 
-		setTicks( true );
-
+	// Redo the tickmarks for the last slider in the slider list.
+	//
+	// The implementation is not obvious, so let's explain:  We ALWAYS have tickmarks
+	// on the LAST slider. Sometimes the slider is not shown, and then we just don't bother.
+	//
+	// a) So, if the last slider has tickmarks, we can always call setTicks(true).
+	//
+	// b) if the last slider has NO tickmarks, there are no tickmarks at all, and we
+	// don't need to redo the tickmarks.
+	QSlider *slider = qobject_cast<QSlider *>(ref_sliders.last());
+	if (slider!=nullptr && slider->tickPosition()!=QSlider::NoTicks) setTicks(true);
 }
 
 
@@ -833,44 +810,10 @@ MDWSlider::setIcons(bool value)
 	} // if it has an icon
 }
 
-void
-MDWSlider::setColors( QColor high, QColor low, QColor back )
-{
-	for( int i=0; i<m_slidersPlayback.count(); ++i ) {
-		QWidget *slider = m_slidersPlayback[i];
-		KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
-		if ( smallSlider ) smallSlider->setColors( high, low, back );
-	}
-	for( int i=0; i<m_slidersCapture.count(); ++i ) {
-		QWidget *slider = m_slidersCapture[i];
-		KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
-		if ( smallSlider ) smallSlider->setColors( high, low, back );
-	}
-}
-
-void
-MDWSlider::setMutedColors( QColor high, QColor low, QColor back )
-{
-	for( int i=0; i<m_slidersPlayback.count(); ++i ) {
-		QWidget *slider = m_slidersPlayback[i];
-		KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
-		if ( smallSlider ) smallSlider->setGrayColors( high, low, back );
-	}
-	for( int i=0; i<m_slidersCapture.count(); ++i ) {
-		QWidget *slider = m_slidersCapture[i];
-		KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
-		if ( smallSlider ) smallSlider->setGrayColors( high, low, back );
-	}
-}
-
 
 /** This slot is called, when a user has changed the volume via the KMix Slider. */
 void MDWSlider::volumeChange( int )
 {
-//  if ( mixDevice()->id() == "Headphone:0" )
-//  {
-//    qCDebug(KMIX_LOG) << "headphone bug";
-//  }
 	if (!m_slidersPlayback.isEmpty())
 	{
 		++m_waitForSoundSetComplete;
@@ -888,23 +831,21 @@ void MDWSlider::volumeChange( int )
 
 void MDWSlider::volumeChangeInternal(Volume& vol, QList<QAbstractSlider *>& ref_sliders)
 {
+	// Changing from the muted state, so ensure unmuted
+	mixDevice()->setMuted(false);
+
 	if (isStereoLinked())
 	{
-		QAbstractSlider* firstSlider = ref_sliders.first();
-		mixDevice()->setMuted(false);
+		const QAbstractSlider *firstSlider = ref_sliders.first();
 		vol.setAllVolumes(firstSlider->value());
 	}
 	else
 	{
-		for (int i = 0; i < ref_sliders.count(); i++)
-		{
-			if (mixDevice()->isMuted())
-			{   // changing from muted state: unmute (the "if" above is actually superfluous)
-				mixDevice()->setMuted(false);
-			}
-			QAbstractSlider *sliderWidget = ref_sliders[i];
-			vol.setVolume(extraData(sliderWidget).getChid(), sliderWidget->value());
-		} // iterate over all sliders
+		for (int i = 0; i<ref_sliders.count(); ++i)
+		{					// iterate over all sliders
+			const VolumeSlider *vs = qobject_cast<VolumeSlider *>(ref_sliders.at(i));
+			if (vs!=nullptr) vol.setVolume(vs->channelId(), vs->value());
+		}
 	}
 }
 
@@ -947,12 +888,6 @@ void MDWSlider::setMuted(bool value)
 }
 
 
-void MDWSlider::setDisabled( bool hide )
-{
-	emit guiVisibilityChange(this, !hide);
-}
-
-
 /**
  * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which are handled by the
  * KMixWindow class. So for 99.9% of all users, this method is never called.
@@ -963,7 +898,7 @@ void MDWSlider::increaseVolume()
 }
 
 /**
- * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which hare handled by the
+ * This slot is called on a Keyboard Shortcut event, except for the XF86Audio* shortcuts which are handled by the
  * KMixWindow class. So for 99.9% of all users, this method is never called.
  */
 void MDWSlider::decreaseVolume()
@@ -1010,10 +945,6 @@ void MDWSlider::moveStream(bool checked)
  */
 void MDWSlider::update()
 {
-//	  bool debugMe = (mixDevice()->id() == "PCM:0" );
-//	  if (debugMe) qCDebug(KMIX_LOG) << "The update() PCM:0 playback state" << mixDevice()->isMuted()
-//	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
-
 	if ( m_slidersPlayback.count() != 0 || mixDevice()->hasMuteSwitch() )
 		updateInternal(mixDevice()->playbackVolume(), m_slidersPlayback, mixDevice()->isMuted() );
 	if ( m_slidersCapture.count()  != 0 || mixDevice()->captureVolume().hasSwitch() )
@@ -1038,23 +969,17 @@ void MDWSlider::update()
  */
 void MDWSlider::updateInternal(Volume& vol, QList<QAbstractSlider *>& ref_sliders, bool muted)
 {
-//  	  bool debugMe = (mixDevice()->id() == "PCM:0" );
-//	  if (debugMe)
-//	  {
-//	    qCDebug(KMIX_LOG) << "The updateInternal() PCM:0 playback state" << mixDevice()->isMuted()
-//	    << ", vol=" << mixDevice()->playbackVolume().getAvgVolumePercent(Volume::MALL);
-//	  }
-  
 	for (int i = 0; i<ref_sliders.count(); ++i)
-	{
-		QAbstractSlider *slider = ref_sliders.at( i );
-		Volume::ChannelID chid = extraData(slider).getChid();
+	{						// for all sliders
+		VolumeSlider *slider = qobject_cast<VolumeSlider *>(ref_sliders.at(i));
+		if (slider==nullptr) continue;
+
+		Volume::ChannelID chid = slider->channelId();
 		long useVolume = muted ? 0 : vol.getVolumeForGUI(chid);
-		int volume_index;
 
 		QSignalBlocker blocker(slider);
 		// --- Avoid feedback loops START -----------------
-		volume_index = volumeValues.indexOf(useVolume);
+		const int volume_index = volumeValues.indexOf(useVolume);
 		if (volume_index>-1 && --m_waitForSoundSetComplete<1)
 		{
 		    m_waitForSoundSetComplete = 0;
@@ -1067,13 +992,7 @@ void MDWSlider::updateInternal(Volume& vol, QList<QAbstractSlider *>& ref_slider
 			slider->setValue(useVolume);
 		}
 		// --- Avoid feedback loops END -----------------
-
-		KSmallSlider *smallSlider = qobject_cast<KSmallSlider *>(slider);
-		if (smallSlider!=nullptr)		// faster than QObject::inherits()
-		{
-			smallSlider->setGray(mixDevice()->isMuted());
-		}
-	} // for all sliders
+	}
 
 
 	// update mute state
@@ -1102,12 +1021,12 @@ void MDWSlider::updateAccesability()
                         m_slidersCapture[0]->setAccessibleName(m_slidersCapture[0]->toolTip());
         } else {
                 QList<VolumeChannel> vols = mixDevice()->playbackVolume().getVolumes().values();
-                foreach (QAbstractSlider *slider, m_slidersPlayback) {
+                for (QAbstractSlider *slider : m_slidersPlayback) {
                         slider->setAccessibleName(slider->toolTip()+ " (" +Volume::channelNameReadable(vols.first().chid)+')');
                         vols.pop_front();
                 }
                 vols = mixDevice()->captureVolume().getVolumes().values();
-                foreach (QAbstractSlider *slider, m_slidersCapture) {
+                for (QAbstractSlider *slider : m_slidersCapture) {
                         slider->setAccessibleName(slider->toolTip()+ " (" +Volume::channelNameReadable(vols.first().chid)+')');
                         vols.pop_front();
                 }
@@ -1116,14 +1035,10 @@ void MDWSlider::updateAccesability()
 #endif
 
 
-void MDWSlider::showContextMenu(const QPoint &pos)
+void MDWSlider::createContextMenu(QMenu *menu)
 {
-	if (view()==nullptr) return;
-
-	QMenu *menu = view()->getPopup();
-	menu->addSection( QIcon::fromTheme( "kmix" ), mixDevice()->readableName() );
-
-	if (m_moveMenu) {
+	if (m_moveMenu!=nullptr)
+	{
 		MixSet *ms = mixDevice()->moveDestinationMixSet();
 		Q_ASSERT(ms!=nullptr);
 
@@ -1137,8 +1052,9 @@ void MDWSlider::showContextMenu(const QPoint &pos)
 		menu->addMenu( m_moveMenu );
 	}
 
-	if ( m_slidersPlayback.count()>1 || m_slidersCapture.count()>1) {
-		KToggleAction *stereo = qobject_cast<KToggleAction *>(_mdwActions->action("stereo"));
+	if (m_slidersPlayback.count()>1 || m_slidersCapture.count()>1)
+	{
+		KToggleAction *stereo = qobject_cast<KToggleAction *>(channelActions()->action("stereo"));
 		if (stereo!=nullptr) {
 			QSignalBlocker blocker(stereo);
 			stereo->setChecked(!isStereoLinked());
@@ -1146,8 +1062,9 @@ void MDWSlider::showContextMenu(const QPoint &pos)
 		}
 	}
 
-	if ( mixDevice()->captureVolume().hasSwitch() ) {
-		KToggleAction *ta = qobject_cast<KToggleAction *>(_mdwActions->action("recsrc"));
+	if (mixDevice()->captureVolume().hasSwitch())
+	{
+		KToggleAction *ta = qobject_cast<KToggleAction *>(channelActions()->action("recsrc"));
 		if (ta!=nullptr) {
 			QSignalBlocker blocker(ta);
 			ta->setChecked( mixDevice()->isRecSource() );
@@ -1155,27 +1072,15 @@ void MDWSlider::showContextMenu(const QPoint &pos)
 		}
 	}
 
-	if ( mixDevice()->hasMuteSwitch() ) {
-		KToggleAction *ta = qobject_cast<KToggleAction *>(_mdwActions->action("mute"));
+	if (mixDevice()->hasMuteSwitch())
+	{
+		KToggleAction *ta = qobject_cast<KToggleAction *>(channelActions()->action("mute"));
 		if (ta!=nullptr) {
 			QSignalBlocker blocker(ta);
 			ta->setChecked( mixDevice()->isMuted() );
 			menu->addAction( ta );
 		}
 	}
-
-//	QAction *a = _mdwActions->action(  "hide" );
-//	if ( a )
-//		menu->addAction( a );
-
-	QAction *b = _mdwActions->action( "keys" );
-	if (b!=nullptr)
-	{
-		menu->addSeparator();
-		menu->addAction(b);
-	}
-
-	menu->popup(pos);
 }
 
 
@@ -1200,7 +1105,7 @@ void MDWSlider::showMoveMenu()
     m_moveMenu->addSeparator();
 
     // Device actions
-    foreach (const shared_ptr<MixDevice> md, *ms)
+    for (const shared_ptr<MixDevice> md : *ms)
     {
 	act = new QAction(QIcon::fromTheme(md->iconName()), md->readableName(), m_moveMenu);
 	act->setData(md->id());
