@@ -23,18 +23,15 @@
 
 #include <kactioncollection.h>
 #include <kconfig.h>
-#include <kglobalaccel.h>
 #include <kshortcutsdialog.h>
+#include <klocalizedstring.h>
 
-#include <qcursor.h>
-#include <QMenu>
-#include <QMouseEvent>
-#include <qpixmap.h>
+#include <qmenu.h>
+#include <qevent.h>
 
 #include "core/mixer.h"
 #include "core/mixertoolbox.h"
 #include "viewbase.h"
-#include "ksmallslider.h"
 #include "verticaltext.h"
 
 /**
@@ -60,10 +57,14 @@ MixDeviceWidget::MixDeviceWidget(shared_ptr<MixDevice> md, MDWFlags flags, ViewB
    if (m_pctl==nullptr) m_pctl = md->controlProfile();
    Q_ASSERT(m_pctl!=nullptr);
 
-   _mdwActions = new KActionCollection( this );
-   _mdwPopupActions = new KActionCollection( this );
+   m_channelActions = new KActionCollection(this);
+   m_globalActions = new KActionCollection(this);
    m_shortcutsDialog = nullptr;
    
+   QAction *act = m_channelActions->addAction("keys");
+   act->setText(i18n("Channel Shortcuts..."));
+   connect(act, &QAction::triggered, this, &MixDeviceWidget::configureShortcuts);
+
    QString name (md->id());
   /* char* whatsThisChar = whatsthis.toUtf8().data();
    QString w;
@@ -76,32 +77,43 @@ MixDeviceWidget::MixDeviceWidget(shared_ptr<MixDevice> md, MDWFlags flags, ViewB
    }
 }
 
-void MixDeviceWidget::addActionToPopup( QAction *action )
+
+void MixDeviceWidget::configureShortcuts()
 {
-   _mdwActions->addAction( action->objectName(), action );
+    // Dialog for *global* shortcuts of this MDW
+    if (m_shortcutsDialog==nullptr)
+    {
+        m_shortcutsDialog = new KShortcutsDialog(KShortcutsEditor::GlobalAction);
+        m_shortcutsDialog->addCollection(m_globalActions);
+    }
+
+    m_shortcutsDialog->configure();
 }
 
-void MixDeviceWidget::defineKeys()
-{
-   // Dialog for *global* shortcuts of this MDW
-   if ( m_shortcutsDialog == 0 ) {
-      m_shortcutsDialog = new KShortcutsDialog( KShortcutsEditor::GlobalAction );
-      m_shortcutsDialog->addCollection(_mdwPopupActions);
-   }
-   m_shortcutsDialog->configure();
-}
 
 void MixDeviceWidget::contextMenuEvent(QContextMenuEvent *ev)
 {
-    showContextMenu(ev->globalPos());
+    if (view()==nullptr) return;
+    QMenu *menu = view()->getPopup();
+    menu->addSection(QIcon::fromTheme("kmix"), mixDevice()->readableName());
+
+    createContextMenu(menu);
+
+    // The common "Channel Shortcuts" action
+    QAction *act = m_channelActions->action("keys");
+    if (act!=nullptr && !m_globalActions->isEmpty())	// action is available, and
+    {							// there are shortcuts to define
+        menu->addSeparator();
+        menu->addAction(act);
+    }
+
+    menu->popup(ev->globalPos());
 }
 
+
 void MixDeviceWidget::volumeChange( int ) { /* is virtual */ }
-//void MixDeviceWidget::setDisabled( bool ) { /* is virtual */ }
-//void MixDeviceWidget::setVolume( int /*channel*/, int /*vol*/ ) { /* is virtual */ }
-//void MixDeviceWidget::setVolume( Volume /*vol*/ ) { /* is virtual */ }
-//void MixDeviceWidget::update() { /* is virtual */ }
-//void MixDeviceWidget::showContextMenu( const QPoint &pos ) { /* is virtual */ }
+//void MixDeviceWidget::update() { /* is pure virtual */ }
+//void MixDeviceWidget::createContextMenu(QMenu *menu) { /* is pure virtual */ }
 void MixDeviceWidget::setColors( QColor , QColor , QColor ) { /* is virtual */ }
 void MixDeviceWidget::setIcons( bool ) { /* is virtual */ }
 void MixDeviceWidget::setLabeled( bool ) { /* is virtual */ }
